Class: Google::Apis::ParametermanagerV1::ListTemplateVersionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ParametermanagerV1::ListTemplateVersionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/parametermanager_v1/classes.rb,
lib/google/apis/parametermanager_v1/representations.rb,
lib/google/apis/parametermanager_v1/representations.rb
Overview
Message for response to listing TemplateVersions
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#template_versions ⇒ Array<Google::Apis::ParametermanagerV1::TemplateVersion>
The list of TemplateVersions Corresponds to the JSON property
templateVersions. -
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListTemplateVersionsResponse
constructor
A new instance of ListTemplateVersionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListTemplateVersionsResponse
Returns a new instance of ListTemplateVersionsResponse.
147 148 149 |
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 147 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
135 136 137 |
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 135 def next_page_token @next_page_token end |
#template_versions ⇒ Array<Google::Apis::ParametermanagerV1::TemplateVersion>
The list of TemplateVersions
Corresponds to the JSON property templateVersions
140 141 142 |
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 140 def template_versions @template_versions end |
#unreachable ⇒ Array<String>
Unordered list. Locations that could not be reached.
Corresponds to the JSON property unreachable
145 146 147 |
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 145 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
152 153 154 155 156 |
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 152 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @template_versions = args[:template_versions] if args.key?(:template_versions) @unreachable = args[:unreachable] if args.key?(:unreachable) end |