Class: Google::Apis::ParametermanagerV1::ListTemplatesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ParametermanagerV1::ListTemplatesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/parametermanager_v1/classes.rb,
lib/google/apis/parametermanager_v1/representations.rb,
lib/google/apis/parametermanager_v1/representations.rb
Overview
Message for response to listing Templates
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#templates ⇒ Array<Google::Apis::ParametermanagerV1::Template>
The list of Templates Corresponds to the JSON property
templates. -
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListTemplatesResponse
constructor
A new instance of ListTemplatesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListTemplatesResponse
Returns a new instance of ListTemplatesResponse.
178 179 180 |
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 178 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
166 167 168 |
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 166 def next_page_token @next_page_token end |
#templates ⇒ Array<Google::Apis::ParametermanagerV1::Template>
The list of Templates
Corresponds to the JSON property templates
171 172 173 |
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 171 def templates @templates end |
#unreachable ⇒ Array<String>
Unordered list. Locations that could not be reached.
Corresponds to the JSON property unreachable
176 177 178 |
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 176 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
183 184 185 186 187 |
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 183 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @templates = args[:templates] if args.key?(:templates) @unreachable = args[:unreachable] if args.key?(:unreachable) end |