Class: Google::Apis::ParametermanagerV1::Parameter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/parametermanager_v1/classes.rb,
lib/google/apis/parametermanager_v1/representations.rb,
lib/google/apis/parametermanager_v1/representations.rb

Overview

Message describing Parameter resource

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Parameter

Returns a new instance of Parameter.



282
283
284
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 282

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. [Output only] Create time stamp Corresponds to the JSON property createTime

Returns:

  • (String)


244
245
246
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 244

def create_time
  @create_time
end

#formatString

Optional. Specifies the format of a Parameter. Corresponds to the JSON property format

Returns:

  • (String)


249
250
251
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 249

def format
  @format
end

#kms_keyString

Optional. Customer managed encryption key (CMEK) to use for encrypting the Parameter Versions. If not set, the default Google-managed encryption key will be used. Cloud KMS CryptoKeys must reside in the same location as the Parameter. The expected format is projects/*/locations/*/keyRings/*/ cryptoKeys/*. Corresponds to the JSON property kmsKey

Returns:

  • (String)


258
259
260
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 258

def kms_key
  @kms_key
end

#labelsHash<String,String>

Optional. Labels as key value pairs Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


263
264
265
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 263

def labels
  @labels
end

#nameString

Identifier. [Output only] The resource name of the Parameter in the format projects/*/locations/*/parameters/*. Corresponds to the JSON property name

Returns:

  • (String)


269
270
271
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 269

def name
  @name
end

#policy_memberGoogle::Apis::ParametermanagerV1::ResourcePolicyMember

Output-only policy member strings of a Google Cloud resource's built-in identity. Corresponds to the JSON property policyMember



275
276
277
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 275

def policy_member
  @policy_member
end

#update_timeString

Output only. [Output only] Update time stamp Corresponds to the JSON property updateTime

Returns:

  • (String)


280
281
282
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 280

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



287
288
289
290
291
292
293
294
295
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 287

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @format = args[:format] if args.key?(:format)
  @kms_key = args[:kms_key] if args.key?(:kms_key)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @policy_member = args[:policy_member] if args.key?(:policy_member)
  @update_time = args[:update_time] if args.key?(:update_time)
end