Class: Google::Apis::ParametermanagerV1::ParameterManagerService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::ParametermanagerV1::ParameterManagerService
- Defined in:
- lib/google/apis/parametermanager_v1/service.rb
Overview
Parameter Manager API
Parameter Manager is a single source of truth to store, access and manage the lifecycle of your workload parameters. Parameter Manager aims to make management of sensitive application parameters effortless for customers without diminishing focus on security.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://parametermanager.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_project_location_parameter(parent, parameter_object = nil, parameter_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Parameter
Creates a new Parameter in a given project and location.
-
#create_project_location_parameter_version(parent, parameter_version_object = nil, parameter_version_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::ParameterVersion
Creates a new ParameterVersion in a given project, location, and parameter.
-
#create_project_location_template(parent, template_object = nil, request_id: nil, template_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Template
Creates a new Template in a given project and location.
-
#create_project_location_template_version(parent, template_version_object = nil, request_id: nil, template_version_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::TemplateVersion
Creates a new TemplateVersion in a given project, location, and template.
-
#delete_project_location_parameter(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Empty
Deletes a single Parameter.
-
#delete_project_location_parameter_version(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Empty
Deletes a single ParameterVersion.
-
#delete_project_location_template(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Empty
Deletes a single Template.
-
#delete_project_location_template_version(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Empty
Deletes a single TemplateVersion.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Location
Gets information about a location.
-
#get_project_location_parameter(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Parameter
Gets details of a single Parameter.
-
#get_project_location_parameter_version(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::ParameterVersion
Gets details of a single ParameterVersion.
-
#get_project_location_template(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Template
Gets details of a single Template.
-
#get_project_location_template_version(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::TemplateVersion
Gets details of a single TemplateVersion.
-
#initialize ⇒ ParameterManagerService
constructor
A new instance of ParameterManagerService.
-
#list_project_location_parameter_versions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::ListParameterVersionsResponse
Lists ParameterVersions in a given project, location, and parameter.
-
#list_project_location_parameters(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::ListParametersResponse
Lists Parameters in a given project and location.
-
#list_project_location_template_versions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::ListTemplateVersionsResponse
Lists TemplateVersions in a given project, location, and template.
-
#list_project_location_templates(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::ListTemplatesResponse
Lists Templates in a given project and location.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_parameter(name, parameter_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Parameter
Updates a single Parameter.
-
#patch_project_location_parameter_version(name, parameter_version_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::ParameterVersion
Updates a single ParameterVersion.
-
#patch_project_location_template(name, template_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Template
Updates a single Template.
-
#patch_project_location_template_version(name, template_version_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::TemplateVersion
Updates a single TemplateVersion.
-
#render_project_location_parameter_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::RenderParameterVersionResponse
Gets rendered version of a ParameterVersion.
-
#render_project_location_template_version(name, parameter_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::RenderTemplateVersionResponse
Gets rendered version of a TemplateVersion.
Constructor Details
#initialize ⇒ ParameterManagerService
Returns a new instance of ParameterManagerService.
50 51 52 53 54 55 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 50 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-parametermanager_v1', client_version: Google::Apis::ParametermanagerV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
43 44 45 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 43 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
48 49 50 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 48 def quota_user @quota_user end |
Instance Method Details
#create_project_location_parameter(parent, parameter_object = nil, parameter_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Parameter
Creates a new Parameter in a given project and location.
177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 177 def create_project_location_parameter(parent, parameter_object = nil, parameter_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/parameters', ) command.request_representation = Google::Apis::ParametermanagerV1::Parameter::Representation command.request_object = parameter_object command.response_representation = Google::Apis::ParametermanagerV1::Parameter::Representation command.response_class = Google::Apis::ParametermanagerV1::Parameter command.params['parent'] = parent unless parent.nil? command.query['parameterId'] = parameter_id unless parameter_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_parameter_version(parent, parameter_version_object = nil, parameter_version_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::ParameterVersion
Creates a new ParameterVersion in a given project, location, and parameter.
399 400 401 402 403 404 405 406 407 408 409 410 411 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 399 def create_project_location_parameter_version(parent, parameter_version_object = nil, parameter_version_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/versions', ) command.request_representation = Google::Apis::ParametermanagerV1::ParameterVersion::Representation command.request_object = parameter_version_object command.response_representation = Google::Apis::ParametermanagerV1::ParameterVersion::Representation command.response_class = Google::Apis::ParametermanagerV1::ParameterVersion command.params['parent'] = parent unless parent.nil? command.query['parameterVersionId'] = parameter_version_id unless parameter_version_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_template(parent, template_object = nil, request_id: nil, template_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Template
Creates a new Template in a given project and location.
655 656 657 658 659 660 661 662 663 664 665 666 667 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 655 def create_project_location_template(parent, template_object = nil, request_id: nil, template_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/templates', ) command.request_representation = Google::Apis::ParametermanagerV1::Template::Representation command.request_object = template_object command.response_representation = Google::Apis::ParametermanagerV1::Template::Representation command.response_class = Google::Apis::ParametermanagerV1::Template command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['templateId'] = template_id unless template_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_template_version(parent, template_version_object = nil, request_id: nil, template_version_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::TemplateVersion
Creates a new TemplateVersion in a given project, location, and template.
876 877 878 879 880 881 882 883 884 885 886 887 888 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 876 def create_project_location_template_version(parent, template_version_object = nil, request_id: nil, template_version_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/versions', ) command.request_representation = Google::Apis::ParametermanagerV1::TemplateVersion::Representation command.request_object = template_version_object command.response_representation = Google::Apis::ParametermanagerV1::TemplateVersion::Representation command.response_class = Google::Apis::ParametermanagerV1::TemplateVersion command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['templateVersionId'] = template_version_id unless template_version_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_parameter(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Empty
Deletes a single Parameter.
223 224 225 226 227 228 229 230 231 232 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 223 def delete_project_location_parameter(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ParametermanagerV1::Empty::Representation command.response_class = Google::Apis::ParametermanagerV1::Empty command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_parameter_version(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Empty
Deletes a single ParameterVersion.
445 446 447 448 449 450 451 452 453 454 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 445 def delete_project_location_parameter_version(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ParametermanagerV1::Empty::Representation command.response_class = Google::Apis::ParametermanagerV1::Empty command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_template(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Empty
Deletes a single Template.
701 702 703 704 705 706 707 708 709 710 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 701 def delete_project_location_template(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ParametermanagerV1::Empty::Representation command.response_class = Google::Apis::ParametermanagerV1::Empty command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_template_version(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Empty
Deletes a single TemplateVersion.
922 923 924 925 926 927 928 929 930 931 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 922 def delete_project_location_template_version(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ParametermanagerV1::Empty::Representation command.response_class = Google::Apis::ParametermanagerV1::Empty command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Location
Gets information about a location.
77 78 79 80 81 82 83 84 85 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 77 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ParametermanagerV1::Location::Representation command.response_class = Google::Apis::ParametermanagerV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_parameter(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Parameter
Gets details of a single Parameter.
255 256 257 258 259 260 261 262 263 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 255 def get_project_location_parameter(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ParametermanagerV1::Parameter::Representation command.response_class = Google::Apis::ParametermanagerV1::Parameter command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_parameter_version(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::ParameterVersion
Gets details of a single ParameterVersion.
480 481 482 483 484 485 486 487 488 489 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 480 def get_project_location_parameter_version(name, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ParametermanagerV1::ParameterVersion::Representation command.response_class = Google::Apis::ParametermanagerV1::ParameterVersion command.params['name'] = name unless name.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_template(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Template
Gets details of a single Template.
733 734 735 736 737 738 739 740 741 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 733 def get_project_location_template(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ParametermanagerV1::Template::Representation command.response_class = Google::Apis::ParametermanagerV1::Template command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_template_version(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::TemplateVersion
Gets details of a single TemplateVersion.
958 959 960 961 962 963 964 965 966 967 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 958 def get_project_location_template_version(name, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ParametermanagerV1::TemplateVersion::Representation command.response_class = Google::Apis::ParametermanagerV1::TemplateVersion command.params['name'] = name unless name.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_parameter_versions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::ListParameterVersionsResponse
Lists ParameterVersions in a given project, location, and parameter.
524 525 526 527 528 529 530 531 532 533 534 535 536 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 524 def list_project_location_parameter_versions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/versions', ) command.response_representation = Google::Apis::ParametermanagerV1::ListParameterVersionsResponse::Representation command.response_class = Google::Apis::ParametermanagerV1::ListParameterVersionsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_parameters(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::ListParametersResponse
Lists Parameters in a given project and location.
298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 298 def list_project_location_parameters(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/parameters', ) command.response_representation = Google::Apis::ParametermanagerV1::ListParametersResponse::Representation command.response_class = Google::Apis::ParametermanagerV1::ListParametersResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_template_versions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::ListTemplateVersionsResponse
Lists TemplateVersions in a given project, location, and template.
1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 1002 def list_project_location_template_versions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/versions', ) command.response_representation = Google::Apis::ParametermanagerV1::ListTemplateVersionsResponse::Representation command.response_class = Google::Apis::ParametermanagerV1::ListTemplateVersionsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_templates(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::ListTemplatesResponse
Lists Templates in a given project and location.
775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 775 def list_project_location_templates(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/templates', ) command.response_representation = Google::Apis::ParametermanagerV1::ListTemplatesResponse::Representation command.response_class = Google::Apis::ParametermanagerV1::ListTemplatesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the
ListLocationsRequest.name field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 129 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::ParametermanagerV1::ListLocationsResponse::Representation command.response_class = Google::Apis::ParametermanagerV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_parameter(name, parameter_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Parameter
Updates a single Parameter.
351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 351 def patch_project_location_parameter(name, parameter_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ParametermanagerV1::Parameter::Representation command.request_object = parameter_object command.response_representation = Google::Apis::ParametermanagerV1::Parameter::Representation command.response_class = Google::Apis::ParametermanagerV1::Parameter command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_parameter_version(name, parameter_version_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::ParameterVersion
Updates a single ParameterVersion.
577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 577 def patch_project_location_parameter_version(name, parameter_version_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ParametermanagerV1::ParameterVersion::Representation command.request_object = parameter_version_object command.response_representation = Google::Apis::ParametermanagerV1::ParameterVersion::Representation command.response_class = Google::Apis::ParametermanagerV1::ParameterVersion command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_template(name, template_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::Template
Updates a single Template.
828 829 830 831 832 833 834 835 836 837 838 839 840 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 828 def patch_project_location_template(name, template_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ParametermanagerV1::Template::Representation command.request_object = template_object command.response_representation = Google::Apis::ParametermanagerV1::Template::Representation command.response_class = Google::Apis::ParametermanagerV1::Template command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_template_version(name, template_version_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::TemplateVersion
Updates a single TemplateVersion.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 1055 def patch_project_location_template_version(name, template_version_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ParametermanagerV1::TemplateVersion::Representation command.request_object = template_version_object command.response_representation = Google::Apis::ParametermanagerV1::TemplateVersion::Representation command.response_class = Google::Apis::ParametermanagerV1::TemplateVersion command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#render_project_location_parameter_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::RenderParameterVersionResponse
Gets rendered version of a ParameterVersion.
611 612 613 614 615 616 617 618 619 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 611 def render_project_location_parameter_version(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}:render', ) command.response_representation = Google::Apis::ParametermanagerV1::RenderParameterVersionResponse::Representation command.response_class = Google::Apis::ParametermanagerV1::RenderParameterVersionResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#render_project_location_template_version(name, parameter_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParametermanagerV1::RenderTemplateVersionResponse
Gets rendered version of a TemplateVersion.
1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 |
# File 'lib/google/apis/parametermanager_v1/service.rb', line 1091 def render_project_location_template_version(name, parameter_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}:render', ) command.response_representation = Google::Apis::ParametermanagerV1::RenderTemplateVersionResponse::Representation command.response_class = Google::Apis::ParametermanagerV1::RenderTemplateVersionResponse command.params['name'] = name unless name.nil? command.query['parameterVersion'] = parameter_version unless parameter_version.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |