Class: Google::Apis::ParametermanagerV1::ParameterVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/parametermanager_v1/classes.rb,
lib/google/apis/parametermanager_v1/representations.rb,
lib/google/apis/parametermanager_v1/representations.rb

Overview

Message describing ParameterVersion resource

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ParameterVersion

Returns a new instance of ParameterVersion.



340
341
342
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 340

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. [Output only] Create time stamp Corresponds to the JSON property createTime

Returns:

  • (String)


305
306
307
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 305

def create_time
  @create_time
end

#disabledBoolean Also known as: disabled?

Optional. Disabled boolean to determine if a ParameterVersion acts as a metadata only resource (payload is never returned if disabled is true). If true any calls will always default to BASIC view even if the user explicitly passes FULL view as part of the request. A render call on a disabled resource fails with an error. Default value is False. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


314
315
316
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 314

def disabled
  @disabled
end

#kms_key_versionString

Optional. Output only. [Output only] The resource name of the KMS key version used to encrypt the ParameterVersion payload. This field is populated only if the Parameter resource has customer managed encryption key (CMEK) configured. Corresponds to the JSON property kmsKeyVersion

Returns:

  • (String)


322
323
324
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 322

def kms_key_version
  @kms_key_version
end

#nameString

Identifier. [Output only] The resource name of the ParameterVersion in the format projects/*/locations/*/parameters/*/versions/*. Corresponds to the JSON property name

Returns:

  • (String)


328
329
330
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 328

def name
  @name
end

#payloadGoogle::Apis::ParametermanagerV1::ParameterVersionPayload

Message for storing a ParameterVersion resource's payload data Corresponds to the JSON property payload



333
334
335
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 333

def payload
  @payload
end

#update_timeString

Output only. [Output only] Update time stamp Corresponds to the JSON property updateTime

Returns:

  • (String)


338
339
340
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 338

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



345
346
347
348
349
350
351
352
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 345

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @disabled = args[:disabled] if args.key?(:disabled)
  @kms_key_version = args[:kms_key_version] if args.key?(:kms_key_version)
  @name = args[:name] if args.key?(:name)
  @payload = args[:payload] if args.key?(:payload)
  @update_time = args[:update_time] if args.key?(:update_time)
end