Class: Google::Apis::ParametermanagerV1::RenderTemplateVersionResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/parametermanager_v1/classes.rb,
lib/google/apis/parametermanager_v1/representations.rb,
lib/google/apis/parametermanager_v1/representations.rb

Overview

Message describing RenderTemplateVersionResponse resource

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RenderTemplateVersionResponse

Returns a new instance of RenderTemplateVersionResponse.



446
447
448
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 446

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parameter_versionString

Output only. The resource name of the ParameterVersion used to render the template version in the format projects/*/locations/*/parameters/*/versions/* . Corresponds to the JSON property parameterVersion

Returns:

  • (String)


420
421
422
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 420

def parameter_version
  @parameter_version
end

#payloadGoogle::Apis::ParametermanagerV1::TemplateVersionPayload

Message for storing a TemplateVersion resource's payload data Corresponds to the JSON property payload



425
426
427
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 425

def payload
  @payload
end

#rendered_payloadString

Output only. Server generated rendered version of the user provided payload data (TemplateVersionPayload) which has all the variables resolved using the provided parameter version. Corresponds to the JSON property renderedPayload NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


433
434
435
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 433

def rendered_payload
  @rendered_payload
end

#template_formatString

Output only. Format of the template version. Corresponds to the JSON property templateFormat

Returns:

  • (String)


438
439
440
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 438

def template_format
  @template_format
end

#template_versionString

Resource identifier of a TemplateVersion in the format projects/*/locations/*/ templates/*/versions/*. Corresponds to the JSON property templateVersion

Returns:

  • (String)


444
445
446
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 444

def template_version
  @template_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



451
452
453
454
455
456
457
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 451

def update!(**args)
  @parameter_version = args[:parameter_version] if args.key?(:parameter_version)
  @payload = args[:payload] if args.key?(:payload)
  @rendered_payload = args[:rendered_payload] if args.key?(:rendered_payload)
  @template_format = args[:template_format] if args.key?(:template_format)
  @template_version = args[:template_version] if args.key?(:template_version)
end