Class: Google::Apis::ParametermanagerV1::Template

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/parametermanager_v1/classes.rb,
lib/google/apis/parametermanager_v1/representations.rb,
lib/google/apis/parametermanager_v1/representations.rb

Overview

Message describing Template resource

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Template

Returns a new instance of Template.



524
525
526
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 524

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Create time stamp Corresponds to the JSON property createTime

Returns:

  • (String)


501
502
503
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 501

def create_time
  @create_time
end

#formatString

Optional. Specifies the format of a Template. Corresponds to the JSON property format

Returns:

  • (String)


506
507
508
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 506

def format
  @format
end

#labelsHash<String,String>

Optional. Labels as key value pairs Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


511
512
513
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 511

def labels
  @labels
end

#nameString

Identifier. The resource name of the Template in the format projects/*/ locations/*/templates/*. Corresponds to the JSON property name

Returns:

  • (String)


517
518
519
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 517

def name
  @name
end

#update_timeString

Output only. Update time stamp Corresponds to the JSON property updateTime

Returns:

  • (String)


522
523
524
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 522

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



529
530
531
532
533
534
535
# File 'lib/google/apis/parametermanager_v1/classes.rb', line 529

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @format = args[:format] if args.key?(:format)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end